/+ https://issues.dlang.org/show_bug.cgi?id=22853 +/
/* TEST_OUTPUT:
---
fail_compilation/fail22853a.c(1): Error: no type for declarator before `/`
---
*/
